@@ -158,6 +158,33 @@ class TestBestMatch(TestCase):
         best = self.best_match_of(instance={"foo": "bar"}, schema=reordered)
         self.assertEqual(best.validator, "minLength")
 
+    def test_it_prioritizes_matching_union_types(self):
+        schema = {
+            "properties": {
+                "foo": {
+                    "anyOf": [
+                        {"type": ["array", "object"], "minItems": 2},
+                        {"type": ["integer", "string"], "minLength": 10},
+                    ],
+                },
+            },
+        }
+        best = self.best_match_of(instance={"foo": "bar"}, schema=schema)
+        self.assertEqual(best.validator, "minLength")
+
+        reordered = {
+            "properties": {
+                "foo": {
+                    "anyOf": [
+                        {"type": "string", "minLength": 10},
+                        {"type": "array", "minItems": 2},
+                    ],
+                },
+            },
+        }
+        best = self.best_match_of(instance={"foo": "bar"}, schema=reordered)
+        self.assertEqual(best.validator, "minLength")
+
     def test_boolean_schemas(self):
         schema = {"properties": {"foo": False}}
         best = self.best_match_of(instance={"foo": "bar"}, schema=schema)
