@@ -597,6 +597,11 @@ class TestValidationErrorMessages(TestCase):
             "Unevaluated items are not allowed ('bar', 'foo' were unexpected)",
         )
 
+    def test_unevaluated_items_on_invalid_type(self):
+        schema = {"type": "array", "unevaluatedItems": False}
+        message = self.message_for(instance="foo", schema=schema)
+        self.assertEqual(message, "'foo' is not of type 'array'")
+
     def test_unevaluated_properties(self):
         schema = {"type": "object", "unevaluatedProperties": False}
         message = self.message_for(
@@ -612,6 +617,11 @@ class TestValidationErrorMessages(TestCase):
             "('bar', 'foo' were unexpected)",
         )
 
+    def test_unevaluated_properties_on_invalid_type(self):
+        schema = {"type": "object", "unevaluatedProperties": False}
+        message = self.message_for(instance="foo", schema=schema)
+        self.assertEqual(message, "'foo' is not of type 'object'")
+
 
 class TestValidationErrorDetails(TestCase):
     # TODO: These really need unit tests for each individual validator, rather
@@ -1400,7 +1410,7 @@ class MetaSchemaTestsMixin(object):
     # TODO: These all belong upstream
     def test_invalid_properties(self):
         with self.assertRaises(exceptions.SchemaError):
-            self.Validator.check_schema({"properties": {"test": object()}})
+            self.Validator.check_schema({"properties": 12})
 
     def test_minItems_invalid_string(self):
         with self.assertRaises(exceptions.SchemaError):
